# Summary

This repository contains SageMath code for working with *Gröbner crystal structures*, introduced in [this preprint](https://arxiv.org/abs/2510.07560).

## Dependencies

- SageMath ([documentation here](https://doc.sagemath.org/html/en/index.html))
- Macaulay2 ([documentation here](https://www.macaulay2.com))
  - the "gfanInterface" package ([documentation here](https://macaulay2.com/doc/Macaulay2/share/doc/Macaulay2/gfanInterface/html/index.html))
- numpy

## Installation

To install grobnercrystals, run the following in a terminal:

```terminal
sage --pip install grobnercrystals
```

Alternatively, run:

```terminal
sage --pip install git+https://github.com/LiberMagnum/grobnercrystals.git#egg=grobnercrystals
```

## Documentation

Documentation and examples are available at [this website](https://libermagnum.github.io/grobnercrystals/).
